@@ -9,7 +9,7 @@ use JSON::PP qw( encode_json );
 use Encode qw( encode_utf8 );
 
 # ABSTRACT: Dist::Zilla initialization tasks for Plicease
-our $VERSION = '1.95'; # VERSION
+our $VERSION = '1.96'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterMint';
@@ -114,17 +114,19 @@ sub gather_file_appveyor_yml
   my $file = Dist::Zilla::File::InMemory->new({
     name    => '.appveyor.yml',
     content => join("\n",
+      q{---},
+      q{},
       q{install:},
       q{  - choco install strawberryperl},
+      q{  - SET PATH=C:\Perl5\bin;C:\strawberry\c\bin;C:\strawberry\perl\site\bin;C:\strawberry\perl\bin;%PATH%},
       q{  - perl -v},
-      q{  - SET PATH=C:\\strawberry\\c\\bin;C:\\strawberry\\perl\\site\\bin;C:\\strawberry\\perl\\bin;%PATH%},
       q{  - if not exist C:\\Perl5 mkdir C:\\Perl5},
       q{  - SET PERL5LIB=C:/Perl5/lib/perl5},
       q{  - SET PERL_LOCAL_LIB_ROOT=C:/Perl5},
       q{  - SET PERL_MB_OPT=--install_base C:/Perl5},
       q{  - SET PERL_MM_OPT=INSTALL_BASE=C:/Perl5},
       q{  - cpanm -n Dist::Zilla},
-      q{  - cpanm - dzil authordeps --missing | cpanm -n},
+      q{  - dzil authordeps --missing | cpanm -n},
       q{  - dzil listdeps --missing | cpanm -n},
       q{},
       q{build: off},
@@ -354,7 +356,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 1.95
+version 1.96
 
 =head1 DESCRIPTION
 
